@@ -10,6 +10,7 @@ connectors = {
 }
 
 required = ['params','db','q','name']
+optional = ['use_headers']
 
 
 class BaseQuery(object):
@@ -31,6 +32,11 @@ class BaseQuery(object):
       self.__setattr__(k, kwargs[k])
       self.connector.__setattr__(k, kwargs[k])
 
+    for k in optional:
+      if k in optional:
+        self.__setattr__(k, kwargs[k])
+        self.connector.__setattr__(k, kwargs[k])
+
 
   def storeResult(self,out):
     f = open(self.name+".tsv","w")
